<?php
/**
 * Playlist Section options
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */

// Add Playlist section
$wp_customize->add_section( 'music_freak_pro_playlist_section', array(
	'title'             => esc_html__( 'Playlist','music-freak-pro' ),
	'description'       => esc_html__( 'Playlist Section options.', 'music-freak-pro' ),
	'panel'             => 'music_freak_pro_front_page_panel',
) );

// Playlist content enable control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[playlist_section_enable]', array(
	'default'			=> 	$options['playlist_section_enable'],
	'sanitize_callback' => 'music_freak_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Freak_Pro_Switch_Control( $wp_customize, 'music_freak_pro_theme_options[playlist_section_enable]', array(
	'label'             => esc_html__( 'Playlist Section Enable', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_playlist_section',
	'on_off_label' 		=> music_freak_pro_switch_options(),
) ) );

// playlist title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[playlist_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['playlist_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[playlist_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_playlist_section',
	'active_callback' 	=> 'music_freak_pro_is_playlist_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_freak_pro_theme_options[playlist_title]', array(
		'selector'            => '#trending-albums .section-header h2.section-title',
		'settings'            => 'music_freak_pro_theme_options[playlist_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_freak_pro_playlist_title_partial',
    ) );
}

// playlist btn title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[playlist_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['playlist_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[playlist_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_playlist_section',
	'active_callback' 	=> 'music_freak_pro_is_playlist_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_freak_pro_theme_options[playlist_btn_title]', array(
		'selector'            => '#trending-albums .section-header a.more-link',
		'settings'            => 'music_freak_pro_theme_options[playlist_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_freak_pro_playlist_btn_title_partial',
    ) );
}

// playlist btn url setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[playlist_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[playlist_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_playlist_section',
	'active_callback' 	=> 'music_freak_pro_is_playlist_section_enable',
	'type'				=> 'url',
) );

// playlist posts drop down chooser control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[playlist_content]', array(
	'sanitize_callback' => 'music_freak_pro_sanitize_array_int',
) );

$wp_customize->add_control( new Music_Freak_Pro_Multiple_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[playlist_content]', array(
	'label'             => esc_html__( 'Select Multiple Audios', 'music-freak-pro' ),
	'description'       => esc_html__( 'Note: Select 7 audios to justify design', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_playlist_section',
	'choices'			=> music_freak_pro_audio_choices(),
	'active_callback'	=> 'music_freak_pro_is_playlist_section_enable',
) ) );

