<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function music_freak_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-freak-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function music_freak_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-freak-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function music_freak_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-freak-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function music_freak_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-freak-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of audio for post choices.
 * @return Array Array of post ids and name.
 */
function music_freak_pro_audio_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'attachment', 'post_mime_type' => 'audio' ) );
    $choices = array();
    $choices[0] = esc_html__( '--None--', 'music-freak-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'music_freak_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function music_freak_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'music-freak-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'music-freak-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'music-freak-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'music-freak-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'music-freak-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'music-freak-pro' ),
        );

        $output = apply_filters( 'music_freak_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'music_freak_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function music_freak_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'music-freak-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'music-freak-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'music-freak-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'music-freak-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'music-freak-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'music-freak-pro' ),
        );

        $output = apply_filters( 'music_freak_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'music_freak_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function music_freak_pro_site_layout() {
        $music_freak_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'music_freak_pro_site_layout', $music_freak_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'music_freak_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function music_freak_pro_selected_sidebar() {
        $music_freak_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'music-freak-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'music-freak-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'music-freak-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'music-freak-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'music-freak-pro' ),
        );

        $output = apply_filters( 'music_freak_pro_selected_sidebar', $music_freak_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'music_freak_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function music_freak_pro_global_sidebar_position() {
        $music_freak_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'music_freak_pro_global_sidebar_position', $music_freak_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'music_freak_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function music_freak_pro_sidebar_position() {
        $music_freak_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'music_freak_pro_sidebar_position', $music_freak_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'music_freak_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function music_freak_pro_pagination_options() {
        $music_freak_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'music-freak-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'music-freak-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'music-freak-pro' ),
        );

        $output = apply_filters( 'music_freak_pro_pagination_options', $music_freak_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'music_freak_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function music_freak_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'music-freak-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'music-freak-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'music-freak-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'music-freak-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'music-freak-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'music-freak-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'music-freak-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'music-freak-pro' ),
        );
        return apply_filters( 'music_freak_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'music_freak_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function music_freak_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'music-freak-pro' ),
            'off'       => esc_html__( 'Disable', 'music-freak-pro' )
        );
        return apply_filters( 'music_freak_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'music_freak_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function music_freak_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'music-freak-pro' ),
            'off'       => esc_html__( 'No', 'music-freak-pro' )
        );
        return apply_filters( 'music_freak_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'music_freak_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function music_freak_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Main Slider', 'music-freak-pro' ),
            'about'     => esc_html__( 'About Us', 'music-freak-pro' ),
            'playlist'  => esc_html__( 'Playlist', 'music-freak-pro' ),
            'music_video'  => esc_html__( 'Music and Video Playlist', 'music-freak-pro' ),
            'service'   => esc_html__( 'Services', 'music-freak-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'music-freak-pro' ),
            'counter'   => esc_html__( 'Counter', 'music-freak-pro' ),
            'promotion' => esc_html__( 'Promotion', 'music-freak-pro' ),
            'blog'      => esc_html__( 'Blog', 'music-freak-pro' ),
            'cta'       => esc_html__( 'Call to Action', 'music-freak-pro' ),
        );
        return apply_filters( 'music_freak_pro_sortable_sections', $sections );
    }
endif;
