<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */
if ( ! function_exists( 'music_freak_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Music Freak Pro 1.0.0
    */
    function music_freak_pro_add_counter_section() {
        $options = music_freak_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'music_freak_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        music_freak_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'music_freak_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Music Freak Pro 1.0.0
   *
   */
   function music_freak_pro_render_counter_section() {
        $options = music_freak_pro_get_theme_options();
        $count = 1;
        for ( $i=1; $i <= 4 ; $i++ ) { 
            if ( ! empty( $options['counter_title_' . $i] ) && ! empty( $options['counter_value_' . $i] ) )
                $count = $i;
        }
        ?>

        <div id="counter" class="relative page-section">
            <div class="wrapper">
                <div class="counter-wrapper clear col-<?php echo absint( $count ); ?>">
                    <?php for ( $i = 1; $i <= 4; $i++ ) : 
                        if ( ! empty( $options['counter_title_' . $i] ) && ! empty( $options['counter_value_' . $i] ) ) : ?>
                        <div class="counter-item">
                            <div class="counter-icon">
                                <i class="fa <?php echo ! empty( $options['counter_icon_' . $i] ) ? esc_attr( $options['counter_icon_' . $i] ) : 'fa-laptop' ?>" ></i>
                            </div><!-- .counter-icon -->            
                            <h3 class="stat-count"><?php echo esc_html( $options['counter_value_' . $i] ); ?></h3>
                            <span><?php echo esc_html( $options['counter_title_' . $i] ); ?></span>
                        </div><!-- .counter-item -->
                        <?php endif; 
                    endfor; ?>
                </div><!-- .counter-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #counter -->

    <?php }
endif;
